/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Fabian 'x3n' Landau
 *   Co-authors:
 *      ...
 *
 */

/**

    @file SpicedAsteroidBelt.h
    @brief Asteroid belt with lots of parameters. Derived from asteroidField.lua


*/


#ifndef _SpicedAsteroidBelt_H__
#define _SpicedAsteroidBelt_H__

#include "OrxonoxPrereqs.h"

#include <string>
#include <vector>
#include "worldentities/ControllableEntity.h"

#include "../../orxonox/worldentities/pawns/Pawn.h"

namespace orxonox // tolua_export
{

    // tolua_export
    class _OrxonoxExport SpicedAsteroidBelt : public Pawn // need pawn to get tick for clean argument passing
    { // tolua_export

        public:
            SpicedAsteroidBelt(Context* context);// This constructor is for XML access only!

            virtual ~SpicedAsteroidBelt();
            virtual void XMLPort(Element& xmlelement, XMLPort::Mode mode);
            virtual void XMLEventPort(Element& xmlelement, XMLPort::Mode mode) override;
            virtual void tick(float dt) override;


            inline void setCount(float s){this->count = s;}
            inline float getCount(){return this->count;}

            inline void setMineralDensity(float d){this->mDensity = d;}
            inline float getMineralDensity(){return this->mDensity;}

            inline void setPosition(Vector3 v){this->position = v;}
            inline Vector3 getPosition(){return this->position;}

            // inline void setYaw(float y){this->yaw = y;}
            // inline float getYaw(){return this->yaw;}

            // inline void setPitch(float p){this->pitch = p;}
            // inline float getPitch(){return this->pitch;}

            inline void setSegments(int s){this->segments = s;}
            inline int getSegments(){return this->segments;}

            inline void setMaxSize(int i){this->maxSize = i;}
            inline int getMaxSize(){return this->maxSize;}

            inline void setMinSize(int i){this->minSize = i;}
            inline int getMinSize(){return this->minSize;}

            inline void setRadius0(float r0){this->radius0 = r0;}
            inline int getRadius0(){return this->radius0;}

            inline void setRadius1(float r1){this->radius1 = r1;}
            inline int getRadius1(){return this->radius1;}            

            inline void setFog(bool f){this->foggy = f;}
            inline bool isFoggy(){return this->foggy;}

            inline void setFogDensity(float fd){this->fogDensity = fd;}
            inline float getFogDensity(){return this->fogDensity;}


        protected:

            Context* context;

            float count;
            float mDensity; // Mineral density, between 0 and 1;

            Vector3 position;

            // float yaw; 
            // float pitch; 
            int segments;
            
            int maxSize;
            int minSize;

            float radius0;
            float radius1; 

            bool foggy;
            float fogDensity; 

            virtual void create();

        private:
            void registerVariables();

    }; // tolua_export
} // tolua_export

#endif /* _SpicedAsteroidBelt_H__ */
